dsge
====
A simple Python (3+) package for Dynamic Stochastic General Equilibrium (DSGE) models.

This was originally forked from Pablo Winant's (excellent) package
dolo.  (See [https://github.com/EconForge/dolo].)  I wrote this mainly
for my own personal use; as such it may contain bugs, and the
documentation might be lacking in some (many) places.

Installation
------------
```bash
conda install dsge -c eherbst
```

Bugs and Questions
------------------
For bug reports and questions, send me an email at
ed.herbst@gmail.com.  If there is enough interest,
I'll mirror the source on github.
